package com.zbf.system.service;

import java.util.List;

import com.zbf.system.domain.TCallNotice;

/**
 * 【请填写功能名称】Service接口
 *
 * @author tony
 * @date 2024-07-11
 */
public interface ITCallNoticeService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TCallNotice selectTCallNoticeById(String id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tCallNotice 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TCallNotice> selectTCallNoticeList(TCallNotice tCallNotice);

    /**
     * 新增【请填写功能名称】
     *
     * @param tCallNotice 【请填写功能名称】
     * @return 结果
     */
    public int insertTCallNotice(TCallNotice tCallNotice);

    /**
     * 修改【请填写功能名称】
     *
     * @param tCallNotice 【请填写功能名称】
     * @return 结果
     */
    public int updateTCallNotice(TCallNotice tCallNotice);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteTCallNoticeByIds(String[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTCallNoticeById(String id);

    /**
     * 批量禁用【请填写功能名称】
     *
     * @param ids 需要禁用的【请填写功能名称】主键集合
     * @return 结果
     */
    public int disabledTCallNoticeByIds(String[] ids);

    /**
     * 批量启用【请填写功能名称】
     *
     * @param ids 需要启用的【请填写功能名称】主键集合
     * @return 结果
     */
    public int enableTCallNoticeByIds(String[] ids);

    /**
     * 改变状态
     *
     * @param tCallNotice
     * @return 结果
     */
    public int updateStatus(TCallNotice tCallNotice);

    /**
     * 发送通知信息到手持设备
     * @param tCallNotice
     */
    public void sendNotice(TCallNotice tCallNotice);

    /**
     * 更新任务状态
     * @param tCallNotice
     */
    public int updateTaskStatus(TCallNotice tCallNotice);
}

